==> haskell-glob-0.10.1-92-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Glob
version:              0.10.1
visibility:           public
id:                   Glob-0.10.1-9gBHWf9JoGJcrsRIvPT7C
key:                  Glob-0.10.1-9gBHWf9JoGJcrsRIvPT7C
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  48fecdb4e55cd51f040ed6260a3fb710
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/Glob-0.10.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Glob-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Glob-0.10.1
hs-libraries:         HSGlob-0.10.1-9gBHWf9JoGJcrsRIvPT7C
depends:
    base-4.15.0.0 containers-0.6.4.1 directory-1.3.6.1
    dlist-1.0-A8ZakkvDKerBegx9VfkpzR filepath-1.4.2.1
    transformers-0.5.6.2 transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-glob-0.10.1-96-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-glob.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 Glob
version:              0.10.1
visibility:           public
id:                   Glob-0.10.1-HqUgEvDJTpbJYtVR0uip6r
key:                  Glob-0.10.1-HqUgEvDJTpbJYtVR0uip6r
license:              BSD-3-Clause
maintainer:           Matti Niemenmaa <matti.niemenmaa+glob@iki.fi>
author:               Matti Niemenmaa
stability:            provisional
homepage:             http://iki.fi/matti.niemenmaa/glob/
synopsis:             Globbing library
description:
    A library for globbing: matching patterns against file paths.

category:             System
abi:                  2be536d99deade980e73ee0e494c5fe1
exposed:              True
exposed-modules:      System.FilePath.Glob System.FilePath.Glob.Primitive
hidden-modules:
    System.FilePath.Glob.Base System.FilePath.Glob.Directory
    System.FilePath.Glob.Match System.FilePath.Glob.Simplify
    System.FilePath.Glob.Utils

import-dirs:          /usr/lib/ghc-9.0.1/site-local/Glob-0.10.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/Glob-0.10.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/Glob-0.10.1
hs-libraries:         HSGlob-0.10.1-HqUgEvDJTpbJYtVR0uip6r
depends:
    base-4.15.0.0 containers-0.6.4.1 directory-1.3.6.1
    dlist-1.0-A8ZakkvDKerBegx9VfkpzR filepath-1.4.2.1
    transformers-0.5.6.2 transformers-compat-0.7-G46eeHH0vduAN6T7RnrFpu

haddock-interfaces:   /usr/share/doc/haskell-glob/html/Glob.haddock
haddock-html:         /usr/share/doc/haskell-glob/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
